<?php

namespace Ads\Channel\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Ads\Channel\Http\Requests\ChannelAdminRequest;
use Ads\Channel\Interfaces\ChannelRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ChannelAdminController extends AdminController
{
    /**
     * Initialize channel controller.
     *
     * @param type ChannelRepositoryInterface $channel
     *
     * @return type
     */
    public function __construct(ChannelRepositoryInterface $channel)
    {
        $this->model = $channel;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ChannelAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('channel.channel.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('channel::channel.names').' :: ');

        return $this->theme->of('channel::admin.channel.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ChannelAdminRequest $request, $id)
    {
        $channel = $this->model->find($id);

        if (empty($channel)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('channel::admin.channel.new');
        }

        if ($request->wantsJson()) {
            return $channel;
        }

        Former::populate($channel);

        return view('channel::admin.channel.show', compact('channel'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ChannelAdminRequest $request)
    {
        $channel = $this->model->findOrNew(0);
        Former::populate($channel);

        return view('channel::admin.channel.create', compact('channel'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ChannelAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $channel = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('channel::channel.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ChannelAdminRequest $request, $id)
    {
        $channel = $this->model->find($id);

        Former::populate($channel);

        return view('channel::admin.channel.edit', compact('channel'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ChannelAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $channel = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('channel::channel.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ChannelAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('channel::channel.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
