<?php

namespace Ads\Channel\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Ads\Channel\Http\Requests\ChannelUserRequest;
use Ads\Channel\Interfaces\ChannelRepositoryInterface;
use Response;
use User;

class ChannelUserController extends UserController
{
    /**
     * Initialize channel controller.
     *
     * @param type ChannelRepositoryInterface $channel
     *
     * @return type
     */
    public function __construct(ChannelRepositoryInterface $channel)
    {
        $this->model = $channel;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ChannelUserRequest $request)
    {
        $channels = $this->model->all();

        $this->theme->prependTitle(trans('channel::channel.names').' :: ');

        return $this->theme->of('channel::user.channel.index', compact('channels'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ChannelUserRequest $request, $role, $id)
    {
        $channel = $this->model->find($id);

        return $this->theme->of('channel::user.channel.show', compact('channel'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ChannelUserRequest $request)
    {
        $channel = $this->model->findOrNew(0);

        Former::populate($channel);

        return $this->theme->of('channel::user.channel.create', compact('channel'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ChannelUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $channel = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('channel::channel.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ChannelUserRequest $request, $role, $id)
    {
        $channel = $this->model->find($id);

        Former::populate($channel);

        return $this->theme->of('channel::user.channel.edit', compact('channel'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ChannelUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $channel = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('channel::channel.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ChannelUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('channel::channel.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
